==> nextcloud-app-news-16.2.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/sq.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Kërkesa dështoi, s’funksionon lidhja në rrjet!",
    "Request unauthorized. Are you logged in?" : "Kërkesë e paautorizuar. Jeni i futur?",
    "Request forbidden. Are you an admin?" : "Kërkesë e ndaluar. Jeni një përgjegjës?",
    "Token expired or app not enabled! Reload the page!" : "Token-i ka skaduar ose s’është aktivizuar aplikacioni! Ringarkoni faqen!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Gabim i brendshëm serveri! Ju lutemi kontrolloni skedarin tuaj data/nextcloud.log për informacion shtesë!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Kërkesa dështoi, Nextcloud është aktualisht më gjëndjen e mirëmbajtjes!",
    "Unread articles" : "Artikujt e palexuar",
    "News" : "Lajme",
    "Use system cron for updates" : "Përdor sistemin cron për përditësime",
    "Purge interval" : "Interval pastrimi",
    "Maximum read count per feed" : "Numër maksimum leximesh për prurje",
    "Maximum redirects" : "Maksimum ridrejtimesh",
    "Feed fetcher timeout" : "Mbarim kohe për sjellësin e prurjeve",
    "Explore Service URL" : "URL Shërbimi Eksplorimesh",
    "Saved" : "U ruajt",
    "Download" : "Shkarko",
    "Close" : "Mbylle",
    "No articles available" : "Jo artikuj të gatshëm",
    "No unread articles available" : "Pa artikuj të palexuar gati",
    "Open website" : "Hap sajtin",
    "Star article" : "Vëri yll artikullit",
    "Unstar article" : "Hiqja yllin artikullit",
    "Keep article unread" : "Mbaje artikullin si të palexuar",
    "Remove keep article unread" : "Hiqi gjendjen mbaje artikullin të palexuar",
    "Username" : "Emër përdoruesi",
    "by" : "nga",
    "from" : "nga",
    "Play audio" : "Luaje audion",
    "Download audio" : "Shkarko audion",
    "Download video" : "Shkarko videon",
    "Keyboard shortcut" : "Shkurtore tastiere",
    "Description" : "Përshkrim",
    "right" : "djathtas",
    "Jump to next article" : "Hidhu te artikulli pasues",
    "left" : "majtas",
    "Jump to previous article" : "Hidhu te artikulli i mëparshëm",
    "Toggle star article" : "Vëri/hiqi yll artikullit",
    "Star article and jump to next one" : "Vëri yll artikullit dhe hidhu te pasuesi",
    "Toggle keep current article unread" : "Vëri/hiqi gjendjen mbaje artikullin të palexuar",
    "Open article in new tab" : "Hape artikullin në skedë të re",
    "Toggle expand article in compact view" : "Kaloje artikullin e zgjeruar nën pamjen kompakte",
    "Refresh" : "Rifreskoje",
    "Load next feed" : "Ngarko prurjen pasuese",
    "Load previous feed" : "Ngarko prurjen e mëparshme",
    "Load next folder" : "Ngarko dosjen pasuese",
    "Load previous folder" : "Ngarko dosjen e mëparshme",
    "Scroll to active navigation entry" : "Rrëshqiteni që të aktivizohet lëvizja për elementin",
    "Focus search field" : "Kaloje fokusin te fusha e kërkimeve",
    "Mark current article's feed/folder read" : "Shënoje prurjen/dosjen e artikullit të tanishëm si të lexuar",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zbulohet modaliteti Ajax ose webcron! Feedet tuaja nuk do të përditësohen!",
    "How to set up the operating system cron" : "Si të rregullohet cron-i i sistemit operativ",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instaloni dhe rregulloni për punë një përditësues paralel më të shpejtë që përdor për përditësime API-n e aplikacionit Lajme",
    "Subscribe" : "Pajtohuni",
    "Web address" : "Adresë Web",
    "Feed exists already!" : "Prurja ekziston tashmë!",
    "Folder" : "Dosje",
    "No folder" : "Pa dosje",
    "New folder" : "Dosje e re",
    "Folder name" : "Emër dosjeje",
    "Go back" : "Kthehuni mbrapsht",
    "Folder exists already!" : "Ka një dosje të tillë!",
    "Credentials" : "Kredenciale",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Kredencialet HTTP Basic Auth duhet të depozitohen të pafshehtëzuara! Cilido që ka hyrje te shërbyesi ose te baza e të dhënave do të jetë në gjendje të hyjë në to!",
    "Password" : "Fjalëkalim",
    "New Folder" : "Dosje e Re",
    "Create" : "Krijoje",
    "Explore" : "Eksploroni",
    "Update failed more than 50 times" : "Përditësimi dështoi më shumë se 50 herë",
    "Deleted feed" : "Prurja u fshi",
    "Undo delete feed" : "Zhbëje fshirjen e prurjes",
    "Rename" : "Riemërtojeni",
    "Menu" : "Menu",
    "Mark read" : "Shëno të lexuar",
    "Unpin from top" : "Shfiksoje prej kreut",
    "Pin to top" : "Fikstoje në krye",
    "Newest first" : "Më të rejat në fillim",
    "Oldest first" : "Më të vjetrat në fillim",
    "Default order" : "Rradhë e parazgjedhur",
    "Enable full text" : "Aktivizo tekst të plotë",
    "Disable full text" : "Çaktivizo tekstin e plotë",
    "Unread updated" : "Përditësim i pa lexuar",
    "Ignore updated" : "Injoro përditësimin",
    "Open feed URL" : "Hap furnizimin URL",
    "Delete" : "Fshij",
    "Dismiss" : "Mos e merr parasysh",
    "Collapse" : "Tkurre",
    "Deleted folder" : "Dosja u fshi",
    "Undo delete folder" : "Zhbëje fshirjen e dosjes",
    "Starred" : "Me yll",
    "All articles" : "Krejt artikujt",
    "Settings" : "Rregullimet",
    "Disable mark read through scrolling" : "Çaktivizo shënime si të lexuar gjatë rrëshqitjesh",
    "Compact view" : "Pamje kompakte",
    "Expand articles on key navigation" : "Zgjeroji artikujt kur lëvizet me tastierë",
    "Show all articles" : "Shfaqi krejt artikujt",
    "Reverse ordering (oldest on top)" : "Renditje e përmbusyr (më të vjetrat në krye)",
    "Subscriptions (OPML)" : "Pajtime (OPML)",
    "Import" : "Importo",
    "Export" : "Eksporto",
    "Error when importing: File does not contain valid OPML" : "Gabim gjatë importimit: Skedari nuk përmbaj OPML të vlefshëm",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Gabim gjatë importimit: OPML-ja nuk përmban prurje, as dosje të vlefshme",
    "Unread/Starred Articles" : "Artikuj të Palexuar/Me yll",
    "Error when importing: file does not contain valid JSON" : "Gabim gjatë importimit: kartela nuk përmban JSON të vlefshëm",
    "Help" : "Ndihmë",
    "Keyboard shortcuts" : "Shkurtore tastiere",
    "Documentation" : "Dokumentim",
    "Report a bug" : "Njoftoni një të metë"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-19.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/sq.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Kërkesa dështoi, s’funksionon lidhja në rrjet!",
    "Request unauthorized. Are you logged in?" : "Kërkesë e paautorizuar. Jeni i futur?",
    "Token expired or app not enabled! Reload the page!" : "Token-i ka skaduar ose s’është aktivizuar aplikacioni! Ringarkoni faqen!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Gabim i brendshëm serveri! Ju lutemi kontrolloni skedarin tuaj data/nextcloud.log për informacion shtesë!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Kërkesa dështoi, Nextcloud është aktualisht më gjëndjen e mirëmbajtjes!",
    "Unread articles" : "Artikujt e palexuar",
    "News" : "Lajme",
    "Shared with me" : "Ndarë me mua",
    "Use system cron for updates" : "Përdor sistemin cron për përditësime",
    "Maximum read count per feed" : "Numër maksimum leximesh për prurje",
    "Maximum redirects" : "Maksimum ridrejtimesh",
    "Feed fetcher timeout" : "Mbarim kohe për sjellësin e prurjeve",
    "Explore Service URL" : "URL Shërbimi Eksplorimesh",
    "Download" : "Shkarko",
    "Close" : "Mbylle",
    "No articles available" : "Jo artikuj të gatshëm",
    "No unread articles available" : "Pa artikuj të palexuar gati",
    "Open website" : "Hap sajtin",
    "Star article" : "Vëri yll artikullit",
    "Unstar article" : "Hiqja yllin artikullit",
    "Keep article unread" : "Mbaje artikullin si të palexuar",
    "Remove keep article unread" : "Hiqi gjendjen mbaje artikullin të palexuar",
    "Share" : "Shpërndaje",
    "Username" : "Emër përdoruesi",
    "by" : "nga",
    "from" : "nga",
    "Play audio" : "Luaje audion",
    "Download audio" : "Shkarko audion",
    "Download video" : "Shkarko videon",
    "Keyboard shortcut" : "Shkurtore tastiere",
    "Description" : "Përshkrim",
    "right" : "djathtas",
    "Jump to next article" : "Hidhu te artikulli pasues",
    "left" : "majtas",
    "Jump to previous article" : "Hidhu te artikulli i mëparshëm",
    "Toggle star article" : "Vëri/hiqi yll artikullit",
    "Star article and jump to next one" : "Vëri yll artikullit dhe hidhu te pasuesi",
    "Toggle keep current article unread" : "Vëri/hiqi gjendjen mbaje artikullin të palexuar",
    "Open article in new tab" : "Hape artikullin në skedë të re",
    "Toggle expand article in compact view" : "Kaloje artikullin e zgjeruar nën pamjen kompakte",
    "Refresh" : "Rifreskoje",
    "Load next feed" : "Ngarko prurjen pasuese",
    "Load previous feed" : "Ngarko prurjen e mëparshme",
    "Load previous folder" : "Ngarko dosjen e mëparshme",
    "Load next folder" : "Ngarko dosjen pasuese",
    "Scroll to active navigation entry" : "Rrëshqiteni që të aktivizohet lëvizja për elementin",
    "Mark current article's feed/folder read" : "Shënoje prurjen/dosjen e artikullit të tanishëm si të lexuar",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zbulohet modaliteti Ajax ose webcron! Feedet tuaja nuk do të përditësohen!",
    "How to set up the operating system cron" : "Si të rregullohet cron-i i sistemit operativ",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instaloni dhe rregulloni për punë një përditësues paralel më të shpejtë që përdor për përditësime API-n e aplikacionit Lajme",
    "Subscribe" : "Pajtohuni",
    "Web address" : "Adresë Web",
    "Feed exists already!" : "Prurja ekziston tashmë!",
    "Folder" : "Dosje",
    "No folder" : "Pa dosje",
    "New folder" : "Dosje e re",
    "Folder name" : "Emër dosjeje",
    "Go back" : "Kthehuni mbrapsht",
    "Folder exists already!" : "Ka një dosje të tillë!",
    "Credentials" : "Kredenciale",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Kredencialet HTTP Basic Auth duhet të depozitohen të pafshehtëzuara! Cilido që ka hyrje te shërbyesi ose te baza e të dhënave do të jetë në gjendje të hyjë në to!",
    "Password" : "Fjalëkalim",
    "New Folder" : "Dosje e Re",
    "Create" : "Krijoje",
    "Explore" : "Eksploroni",
    "Update failed more than 50 times" : "Përditësimi dështoi më shumë se 50 herë",
    "Deleted feed" : "Prurja u fshi",
    "Undo delete feed" : "Zhbëje fshirjen e prurjes",
    "Rename" : "Riemërtojeni",
    "Menu" : "Menu",
    "Mark read" : "Shëno të lexuar",
    "Unpin from top" : "Shfiksoje prej kreut",
    "Pin to top" : "Fikstoje në krye",
    "Newest first" : "Më të rejat në fillim",
    "Oldest first" : "Më të vjetrat në fillim",
    "Default order" : "Rradhë e parazgjedhur",
    "Enable full text" : "Aktivizo tekst të plotë",
    "Disable full text" : "Çaktivizo tekstin e plotë",
    "Unread updated" : "Përditësim i pa lexuar",
    "Ignore updated" : "Injoro përditësimin",
    "Open feed URL" : "Hap furnizimin URL",
    "Delete" : "Fshij",
    "Dismiss" : "Mos e merr parasysh",
    "Collapse" : "Tkurre",
    "Deleted folder" : "Dosja u fshi",
    "Undo delete folder" : "Zhbëje fshirjen e dosjes",
    "Starred" : "Me yll",
    "All articles" : "Krejt artikujt",
    "Settings" : "Rregullimet",
    "Disable mark read through scrolling" : "Çaktivizo shënime si të lexuar gjatë rrëshqitjesh",
    "Compact view" : "Pamje kompakte",
    "Expand articles on key navigation" : "Zgjeroji artikujt kur lëvizet me tastierë",
    "Show all articles" : "Shfaqi krejt artikujt",
    "Reverse ordering (oldest on top)" : "Renditje e përmbusyr (më të vjetrat në krye)",
    "Subscriptions (OPML)" : "Pajtime (OPML)",
    "Import" : "Importo",
    "Export" : "Eksporto",
    "Error when importing: File does not contain valid OPML" : "Gabim gjatë importimit: Skedari nuk përmbaj OPML të vlefshëm",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Gabim gjatë importimit: OPML-ja nuk përmban prurje, as dosje të vlefshme",
    "Unread/Starred Articles" : "Artikuj të Palexuar/Me yll",
    "Error when importing: file does not contain valid JSON" : "Gabim gjatë importimit: kartela nuk përmban JSON të vlefshëm",
    "Help" : "Ndihmë",
    "Keyboard shortcuts" : "Shkurtore tastiere",
    "Documentation" : "Dokumentim",
    "Report a bug" : "Njoftoni një të metë"
},
"nplurals=2; plural=(n != 1);");
